@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2000, 2016, Oracle and/or its affiliates. All rights reserved.
+   Copyright (c) 2000, 2017, Oracle and/or its affiliates. All rights reserved.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -66,6 +66,7 @@ static bool save_index(Sort_param *param, uint count,
                        Filesort_info *table_sort);
 static uint suffix_length(ulong string_length);
 static SORT_ADDON_FIELD *get_addon_fields(ulong max_length_for_sort_data,
+                                          TABLE *const table,
                                           Field **ptabfield,
                                           uint sortlength, uint *plength);
 static void unpack_addon_fields(struct st_sort_addon_field *addon_field,
@@ -90,6 +91,7 @@ void Sort_param::init_for_filesort(uint sortlen, TABLE *table,
       to sorted fields and get its total length in addon_length.
     */
     addon_field= get_addon_fields(max_length_for_sort_data,
+                                  table,
                                   table->field, sort_length, &addon_length);
   }
   if (addon_field)
@@ -1226,7 +1228,7 @@ void make_sortkey(Sort_param *param, uchar *to, uchar *ref_pos)
 
 static void register_used_fields(Sort_param *param)
 {
-  reg1 SORT_FIELD *sort_field;
+  SORT_FIELD *sort_field;
   TABLE *table=param->sort_form;
   MY_BITMAP *bitmap= table->read_set;
 
@@ -1457,7 +1459,7 @@ bool check_if_pq_applicable(Opt_trace_context *trace,
 int merge_many_buff(Sort_param *param, uchar *sort_buffer,
                     BUFFPEK *buffpek, uint *maxbuffer, IO_CACHE *t_file)
 {
-  register uint i;
+  uint i;
   IO_CACHE t_file2,*from_file,*to_file,*temp;
   BUFFPEK *lastbuff;
   DBUG_ENTER("merge_many_buff");
@@ -1515,7 +1517,7 @@ cleanup:
 uint read_to_buffer(IO_CACHE *fromfile, BUFFPEK *buffpek,
 		    uint rec_length)
 {
-  register uint count;
+  uint count;
   uint length;
 
   if ((count=(uint) min((ha_rows) buffpek->max_keys,buffpek->count)))
@@ -1767,7 +1769,7 @@ int merge_buffers(Sort_param *param, IO_CACHE *from_file,
     }
     else
     {
-      register uchar *end;
+      uchar *end;
       strpos= buffpek->key+offset;
       for (end= strpos+buffpek->mem_count*rec_length ;
            strpos != end ;
@@ -1953,6 +1955,7 @@ sortlength(THD *thd, SORT_FIELD *sortorder, uint s_length,
 
 static SORT_ADDON_FIELD *
 get_addon_fields(ulong max_length_for_sort_data,
+                 TABLE *const table,
                  Field **ptabfield, uint sortlength, uint *plength)
 {
   Field **pfield;
@@ -1961,7 +1964,7 @@ get_addon_fields(ulong max_length_for_sort_data,
   uint length= 0;
   uint fields= 0;
   uint null_fields= 0;
-  MY_BITMAP *read_set= (*ptabfield)->table->read_set;
+  MY_BITMAP *read_set= table->read_set;
 
   /*
     If there is a reference to a field in the query add it
