@@ -422,6 +422,7 @@ bool sp_head::execute(THD *thd, bool merge_da_on_success)
   bool cur_db_changed= FALSE;
   bool err_status= FALSE;
   uint ip= 0;
+  bool save_enable_slow_log = thd->enable_slow_log;
   sql_mode_t save_sql_mode;
   bool save_abort_on_warning;
   Query_arena *old_arena;
@@ -649,6 +650,8 @@ bool sp_head::execute(THD *thd, bool merge_da_on_success)
 
     thd->m_digest= parent_digest;
 
+    thd->enable_slow_log= save_enable_slow_log;
+
     if (i->free_list)
       cleanup_items(i->free_list);
 
@@ -1293,7 +1296,8 @@ bool sp_head::execute_procedure(THD *thd, List<Item> *args)
     DBUG_PRINT("info",(" %.*s: eval args done", (int) m_name.length, 
                        m_name.str));
   }
-  if (!(m_flags & LOG_SLOW_STATEMENTS || opt_log_slow_sp_statements) && thd->enable_slow_log)
+  if (!(m_flags & LOG_SLOW_STATEMENTS || opt_log_slow_sp_statements == 1)
+      && thd->enable_slow_log)
   {
     DBUG_PRINT("info", ("Disabling slow log for the execution"));
     save_enable_slow_log= true;
@@ -1763,10 +1767,10 @@ bool sp_head::show_routine_code(THD *thd)
     */
     if (ip != i->get_ip())
     {
-      const char *format= "Instruction at position %u has m_ip=%u";
+      const char format[]= "Instruction at position %u has m_ip=%u";
       char tmp[sizeof(format) + 2 * sizeof(uint) + 1];
 
-      sprintf(tmp, format, ip, i->get_ip());
+      snprintf(tmp, sizeof(tmp), format, ip, i->get_ip());
       /*
         Since this is for debugging purposes only, we don't bother to
         introduce a special error code for it.
@@ -1958,7 +1962,7 @@ bool sp_head::add_used_tables_to_table_list(THD *thd,
 bool sp_head::check_show_access(THD *thd, bool *full_access)
 {
   TABLE_LIST tables;
-  memset(&tables, 0, sizeof(tables));
+  memset(static_cast<void*>(&tables), 0, sizeof(tables));
   tables.db= (char*) "mysql";
   tables.table_name= tables.alias= (char*) "proc";
 
