@@ -1,4 +1,4 @@
-/* Copyright (c) 2000, 2010, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2000, 2016, Oracle and/or its affiliates. All rights reserved.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -62,8 +62,8 @@ static int test_if_open(struct file_info *key,element_count count,
 static void fix_blob_pointers(MI_INFO *isam,uchar *record);
 static int test_when_accessed(struct file_info *key,element_count count,
 			      struct st_access_param *access_param);
-static void file_info_free(void* key, TREE_FREE action __attribute__((unused)),
-                           void *param __attribute__((unused)));
+static void file_info_free(void* key, TREE_FREE action MY_ATTRIBUTE((unused)),
+                           const void *param MY_ATTRIBUTE((unused)));
 static int close_some_file(TREE *tree);
 static int reopen_closed_file(TREE *tree,struct file_info *file_info);
 static int find_record_with_key(struct file_info *file_info,uchar *record);
@@ -91,7 +91,7 @@ int main(int argc, char **argv)
   log_filename=myisam_log_filename;
   get_options(&argc,&argv);
   /* Number of MyISAM files we can have open at one time */
-  max_files= (my_set_max_open_files(min(max_files,8))-6)/2;
+  max_files= (my_set_max_open_files(MY_MIN(max_files, 8)) - 6) / 2;
   if (update)
     printf("Trying to %s MyISAM files according to log '%s'\n",
 	   (recover ? "recover" : "update"),log_filename);
@@ -328,7 +328,7 @@ static int examine_log(char * file_name, char **table_names)
   }
 
   init_io_cache(&cache,file,0,READ_CACHE,start_offset,0,MYF(0));
-  bzero((uchar*) com_count,sizeof(com_count));
+  memset(com_count, 0, sizeof(com_count));
   init_tree(&tree,0,0,sizeof(file_info),(qsort_cmp2) file_info_compare,1,
             file_info_free, NULL);
   (void) init_key_cache(dflt_key_cache,KEY_CACHE_BLOCK_SIZE,KEY_CACHE_SIZE,
@@ -696,7 +696,7 @@ static int read_string(IO_CACHE *file, uchar* *to, uint length)
 }				/* read_string */
 
 
-static int file_info_compare(void* cmp_arg __attribute__((unused)),
+static int file_info_compare(void* cmp_arg MY_ATTRIBUTE((unused)),
 			     void *a, void *b)
 {
   long lint;
@@ -710,7 +710,7 @@ static int file_info_compare(void* cmp_arg __attribute__((unused)),
 	/* ARGSUSED */
 
 static int test_if_open (struct file_info *key,
-			 element_count count __attribute__((unused)),
+			 element_count count MY_ATTRIBUTE((unused)),
 			 struct test_if_open_param *param)
 {
   if (!strcmp(key->name,param->name) && key->id > param->max_id)
@@ -738,7 +738,7 @@ static void fix_blob_pointers(MI_INFO *info, uchar *record)
 	/* ARGSUSED */
 
 static int test_when_accessed (struct file_info *key,
-			       element_count count __attribute__((unused)),
+			       element_count count MY_ATTRIBUTE((unused)),
 			       struct st_access_param *access_param)
 {
   if (key->accessed < access_param->min_accessed && ! key->closed)
@@ -750,8 +750,8 @@ static int test_when_accessed (struct file_info *key,
 }
 
 
-static void file_info_free(void* key, TREE_FREE action __attribute__((unused)),
-                           void *param __attribute__((unused)))
+static void file_info_free(void* key, TREE_FREE action MY_ATTRIBUTE((unused)),
+                           const void *param MY_ATTRIBUTE((unused)))
 {
   struct file_info *fileinfo= (struct file_info*)key;
   DBUG_ENTER("file_info_free");
